%define major 37
%define libname %mklibname %{name} %{major}

# Hack, we need bigger update of the spec to handle usrmove
%define _bindir /bin
%define _libdir /%_lib

%bcond_with mono
%bcond_with php
%bcond_with java

%global languages cpp ruby python %{?with mono: csharp}%{?with java: java}%{?with php: php}

Name:		ice
Version:	3.7.10
Release:	%mkrel 3
Summary:	The Ice base runtime and services

Group:		Networking/WWW
License:	GPLv2 with exceptions
URL:		https://zeroc.com/
Source0:	https://github.com/zeroc-ice/ice/archive/v%{version}/%{name}-%{version}.tar.gz
Source3:        IceGridAdmin.desktop
Source4:        Ice-README.Mageia
Source5:        glacier2router.conf
Source6:        glacier2router.service
Source7:        icegridnode.conf
Source8:        icegridnode.service
Source9:        icegridregistry.conf
Source10:       icegridregistry.service
Source11:       ice.ini
Source12:       ice.pth

# Upstream patches

# Do not build for x86_64 on i586
Patch3:		ice-3.7.3-i586.patch
# python3.8 linking
Patch4:		ice-python3.8.patch

BuildRequires:	db5.3-devel
BuildRequires:	expat-devel
BuildRequires:	openssl-devel
BuildRequires:	bzip2-devel
BuildRequires:	lmdb-devel
%if %{with php}
BuildRequires:	php
BuildRequires:	php-devel
%endif
BuildRequires:	ruby >= 1.8
BuildRequires:	ruby-devel >= 1.8
BuildRequires:	python3-devel
%if %{with mono}
BuildRequires:	mono
BuildRequires:	mono-devel
%endif
BuildRequires:	mcpp-devel >= 2.7.1
BuildRequires:	dos2unix
%if %{with java}
BuildRequires:	ant
BuildRequires:	java-devel
BuildRequires:	jpackage-utils
BuildRequires:	jgoodies-forms >= 1.6.0
BuildRequires:	jgoodies-looks
BuildRequires:	jgoodies-common
%endif
BuildRequires:  imagemagick
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(libedit)

Requires:	%{libname} = %{version}-%{release}

Obsoletes:	icegrid-gui < 3.5.1-8
Obsoletes:	ice-java < 3.5.1-8
Obsoletes:	ice-java-devel < 3.5.1-8

%description
Ice is a modern alternative to object middleware such as CORBA or
COM/DCOM/COM+.  It is easy to learn, yet provides a powerful network
infrastructure for demanding technical applications. It features an
object-oriented specification language, easy to use C++, C#, Java,
Python, Ruby, PHP, and Visual Basic mappings, a highly efficient
protocol, asynchronous method invocation and dispatch, dynamic
transport plug-ins, TCP/IP and UDP/IP support, SSL-based security, a
firewall solution, and much more.

# All of the other Ice packages also get built by this SRPM.

%package -n %{libname}
Summary:	Ice shared libraries
Group:		System/Libraries

%description -n %{libname}
This package contains Ice shared libraries.

%package servers
Summary:	Ice services to run through /etc/rc.d/init.d
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
# Requirements for the users
Requires(pre):	shadow-utils
# Requirements for the init.d services
%description servers
Ice services to run through /etc/rc.d/init.d

%package devel
Summary:	Tools for developing Ice applications in C++
Group:		Development/C++
Provides:	ice-c++-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description devel
Tools for developing Ice applications in C++.

%if %{with java}
%package java
Summary:	The Ice runtime for Java
Group:		System/Libraries
Requires:	java >= 1.5.0
Requires:	db4.8
Requires:	%{libname} = %{version}-%{release}

%description java
The Ice runtime for Java

%package java-devel
Summary:	Tools for developing Ice applications in Java
Group:		Development/Java
Requires:	%{name}-java = %{version}-%{release}

%description java-devel
Tools for developing Ice applications in Java.

%package -n icegrid-gui
Summary:	IceGrid Admin Tool
Group:		Development/Other
Requires:	java
Requires:	%{name}-java = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:       jgoodies-forms >= 1.6.0
Requires:       jgoodies-looks
Requires:       jgoodies-common

%description -n icegrid-gui
Graphical administration tool for IceGrid
%endif

%if %{with mono}
%package csharp
Summary:	The Ice runtime for C#
Group:		System/Libraries
Provides:	ice-dotnet = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	mono >= 1.2.2
%description csharp
The Ice runtime for C#

%package csharp-devel
Summary:	Tools for developing Ice applications in C#
Group:		Development/C#
Requires:	%{name}-csharp = %{version}-%{release}
Requires:	pkgconfig
%description csharp-devel
Tools for developing Ice applications in C#.
%endif

%package ruby
Summary:	The Ice runtime for Ruby applications
Group:		Development/Ruby
Requires:	%{libname} = %{version}-%{release}
Requires:	ruby >= 1.8

%description ruby
The Ice runtime for Ruby applications.

%package ruby-devel
Summary:	Tools for developing Ice applications in Ruby
Group:		Development/Ruby
Requires:	%{name}-ruby = %{version}-%{release}

%description ruby-devel
Tools for developing Ice applications in Ruby.

%package -n python3-%{name}
Summary:	The Ice runtime for Python applications
Group:		Development/Python
Requires:	%{libname} = %{version}-%{release}
Requires:	python3
Provides:	python-%{name} = %{version}-%{release}
Obsoletes:	python-%{name} < 3.7.3-2

%description -n python3-%{name}
The Ice runtime for Python applications.

%package -n python3-%{name}-devel
Summary:	Tools for developing Ice applications in Python
Group:		Development/Python
Requires:	python3-%{name} = %{version}-%{release}
Provides:	python-%{name}-devel = %{version}-%{release}
Obsoletes:      python-%{name}-devel < 3.7.3-2

%description -n python3-%{name}-devel
Tools for developing Ice applications in Python.

%if %{with php}
%package -n php-%{name}
Summary:	The Ice runtime for PHP applications
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	php

%description -n php-%{name}
The Ice runtime for PHP applications.
%endif

%prep
%setup -q
%autopatch -p1

%build
%if %{with java}
# Set the CLASSPATH correctly for the Java compile
export CLASSPATH=`build-classpath db5.3 jgoodies-forms jgoodies-looks jgoodies-common`

# Set JAVA_HOME
export JAVA_HOME=%{java_home}
%endif

# Compile the main Ice runtime
%make_build \
	CXXFLAGS="%{optflags} -fPIC -fpermissive -pthread" \
	CFLAGS="%{optflags} -fPIC -fpermissive -pthread" \
	embedded_runpath_prefix="" libsubdir=%{_lib} \
	PYTHON=%{__python3} \
	LANGUAGES="%{languages}"

%if %{with java}
# Rebuild the Java ImportKey class
pushd %{_builddir}/Ice-%{version}/cpp/src/ca
rm *.class
javac ImportKey.java
popd

pushd %{_builddir}/Ice-%{version}/java/resources/icons
# Create the IceGrid icon
convert icegrid.ico temp.png
mv temp-8.png icegrid.png
rm temp*.png
popd
%endif

%install
%if %{with java}
# For some reason it tries to rebuild icegridgui here, so set the CLASSPATH again
export CLASSPATH=`build-classpath db4.8 jgoodies-forms jgoodies-looks jgoodies-common`
export JAVA_HOME=%{java_home}
%endif

# Do the basic "make install"
make prefix=%{buildroot} GACINSTALL=yes GAC_ROOT=%{buildroot}%{_libdir} embedded_runpath_prefix="" libsubdir=%{_lib} install LANGUAGES="%{languages}"

%if %{with java}
# Move Java stuff where it should be
mkdir -p %{buildroot}%{_javadir}
for file in %{buildroot}/lib/*.jar; do
 mv $file %{buildroot}%{_javadir}
done

## install IceGrid GUI in the right place
mkdir -p %{buildroot}%{_datadir}/Ice-%{version}
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/
cp -p java/resources/icons/icegrid.png \
   %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/
%jpackage_script IceGridGUI.Main "" "" IceGridGUI:jgoodies-looks:jgoodies-forms:jgoodies-common icegridgui 0

desktop-file-install \
        --dir=%{buildroot}%{_datadir}/applications \
        %{SOURCE3}

# Move the ImportKey.class file
mkdir -p %{buildroot}%{_datadir}/Ice-%{version}
mv %{buildroot}/lib/ImportKey.class %{buildroot}%{_datadir}/Ice-%{version}

%endif

# Move other rpm-specific files into the right place (README, service stuff)
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp -p %{SOURCE4} %{buildroot}/%{_defaultdocdir}/%{name}/README.Mageia

# There are a couple of files that end up installed in /lib, not %%{_libdir},
# so we try this move too.
%if %{with mono}
mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m0644 -t %{buildroot}%{_libdir}/pkgconfig \
         %{buildroot}/lib/pkgconfig/*.pc
%endif

mv %{buildroot}/include  %{buildroot}/%{_includedir}

# Copy the man pages into the correct directory
mv %{buildroot}/man  %{buildroot}/%{_mandir}

%if %{with mono}
# .NET spec files (for csharp-devel) -- convert the paths
for f in IceGrid Glacier2 IceBox Ice IceStorm IcePatch2;
do
    mv %{buildroot}/usr/lib/mono/$f/$f.xml \
       %{buildroot}%{_prefix}/lib/mono/gac/$f/%{version}.*/
    # fix xml files permissions
    chmod 0644 %{buildroot}%{_prefix}/lib/mono/gac/$f/%{version}.*/*.xml
done
%else
	rm -fv %buildroot%_bindir/slice2cs
	rm -fv %buildroot%_mandir/man1/slice2cs.1*
%endif

%if %{with php}
# Put the PHP stuff into the right place
mkdir -p %{buildroot}%{_sysconfdir}/php.d
mkdir -p %{buildroot}%{_libdir}/php/extensions/
mv %{buildroot}/php/IcePHP.so %{buildroot}%{_libdir}/php/extensions/
install -D -p -m0644 %{SOURCE11} \
	%{buildroot}%{_sysconfdir}/php.d/%{name}.ini
%endif

# Also Ruby and Python -- remove all shebang lines while we're at it
find %{buildroot} -name '*.py' -name '*.rb' | while read f
do
    grep -v '/usr/bin/env' $f > $f.tmp
    mv $f.tmp $f
done
mkdir -p %{buildroot}%{ruby_vendorarchdir}
mv %{buildroot}/ruby/*.so %{buildroot}%{ruby_vendorarchdir}
mkdir -p %{buildroot}%{ruby_vendorlibdir}
mv %{buildroot}/ruby/* %{buildroot}%{ruby_vendorlibdir}
mkdir -p %{buildroot}%{python_sitearch}/
mv %{buildroot}/python/* %{buildroot}%{python3_sitearch}/
cp -p %{SOURCE12} %{buildroot}%{python3_sitearch}

mkdir -p %{buildroot}%{_datadir}/%{name}
mv %{buildroot}/config/* %{buildroot}%{_datadir}/%{name}
mv %{buildroot}/slice %{buildroot}%{_datadir}/%{name}
# Somehow, some files under "slice" end up with executable permissions -- ??
find %{buildroot}%{_datadir}/%{name} -name "*.ice" | xargs chmod a-x

# Put the license files in as documentation
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
mv %{buildroot}/ICE_LICENSE %{buildroot}/LICENSE \
 %{buildroot}%{_defaultdocdir}/%{name}

%if %{with php}
rm -fr %{buildroot}/php
%endif

## install systemd services configuration
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}
## glacier2router
install -p -m0644 %{SOURCE5} %{buildroot}%{_sysconfdir}
install -p -m0644 %{SOURCE6} %{buildroot}%{_unitdir}
## icegridnode
install -p -m0644 %{SOURCE7} %{buildroot}%{_sysconfdir}
install -p -m0644 %{SOURCE8} %{buildroot}%{_unitdir}
## icegridregistry
install -p -m0644 %{SOURCE9} %{buildroot}%{_sysconfdir}
install -p -m0644 %{SOURCE10} %{buildroot}%{_unitdir}

mkdir -p %{buildroot}%{_localstatedir}/lib/icegrid

# Delete those for languages we don't build
rm -f %{buildroot}%{_bindir}/slice2{confluence,js,matlab,objc,swift}
rm -f %{buildroot}%{_mandir}/man1/slice2{confluence,js,matlab,objc,swift}.1*

%pre servers
%_pre_useradd iceuser %{_localstatedir}/lib/icegrid /bin/sh

%post servers
%_post_service icegridregistry
%_post_service icegridnode
%_post_service glacier2router

%preun servers
if [ $1 = 0 ]; then
        %_preun_service icegridregistry
        %_preun_service icegridnode
        %_preun_service glacier2router
fi

%postun servers
if [ "$1" -ge "1" ]; then
        /sbin/service icegridregistry condrestart >/dev/null 2>&1 || :
        /sbin/service icegridnode condrestart >/dev/null 2>&1 || :
        /sbin/service glacier2router condrestart >/dev/null 2>&1 || :
fi

%files
%{_defaultdocdir}/%{name}
%{_bindir}/glacier2router
%{_bindir}/icebox
%{_bindir}/iceboxadmin
%{_bindir}/icebridge
%{_bindir}/icegridadmin
%{_bindir}/icegriddb
%{_bindir}/icegridnode
%{_bindir}/icegridregistry
%{_bindir}/icepatch2calc
%{_bindir}/icepatch2client
%{_bindir}/icepatch2server
%{_bindir}/icestormadmin
%{_bindir}/icestormdb
%{_bindir}/slice2html
%{_datadir}/%{name}
%{_mandir}/man1/glacier2router.1.*
%{_mandir}/man1/icebox.1.*
%{_mandir}/man1/iceboxadmin.1.*
%{_mandir}/man1/icebridge.1.*
%{_mandir}/man1/icegridadmin.1.*
%{_mandir}/man1/icegriddb.1.*
%{_mandir}/man1/icegridnode.1.*
%{_mandir}/man1/icegridregistry.1.*
%{_mandir}/man1/icepatch2calc.1.*
%{_mandir}/man1/icepatch2client.1.*
%{_mandir}/man1/icepatch2server.1.*
%{_mandir}/man1/icestormadmin.1.*
%{_mandir}/man1/icestormdb.1.*
%{_mandir}/man1/slice2html.1.*

%files -n %{libname}
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.%{major}

%files servers
%{_unitdir}/icegridregistry.service
%{_unitdir}/icegridnode.service
%{_unitdir}/glacier2router.service
%config(noreplace) %{_sysconfdir}/icegridregistry.conf
%config(noreplace) %{_sysconfdir}/icegridnode.conf
%config(noreplace) %{_sysconfdir}/glacier2router.conf
%{_localstatedir}/lib/icegrid

%files devel
%{_bindir}/slice2cpp
%{_includedir}/Glacier2
%{_includedir}/Ice
%{_includedir}/IceBox
%{_includedir}/IceGrid
%{_includedir}/IcePatch2
%{_includedir}/IceSSL
%{_includedir}/IceStorm
%{_includedir}/IceUtil
%{_libdir}/*.so
%{_mandir}/man1/slice2cpp.1.*
%if %{without java}
%exclude %{_bindir}/slice2java
%exclude %{_mandir}/man1/slice2java.1.*
%endif
%if %{without php}
%exclude %{_bindir}/slice2php
%exclude %{_mandir}/man1/slice2php.1.*
%endif

%if %{with java}
%files java
%{_javadir}/*.jar
# Exclude the stuff that's in IceGrid and java-devel
%exclude %{_javadir}/IceGridGUI.jar
%exclude %{_javadir}/ant-ice.jar

%files -n icegrid-gui
%{_javadir}/IceGridGUI.jar
%attr(755,root,root) %{_bindir}/icegridgui
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/48x48/apps/icegrid.png

%files java-devel
%{_bindir}/slice2java
%{_javadir}/ant-ice.jar
%{_mandir}/man1/slice2java.1.*
%endif

%if %{with mono}
%files csharp
%{_libdir}/mono/Glacier2/
%{_libdir}/mono/Ice/
%{_libdir}/mono/IceBox/
%{_libdir}/mono/IceGrid/
%{_libdir}/mono/IcePatch2/
%{_libdir}/mono/IceStorm/

%{_libdir}/mono/gac/Glacier2
%{_libdir}/mono/gac/Ice
%{_libdir}/mono/gac/IceBox
%{_libdir}/mono/gac/IceGrid
%{_libdir}/mono/gac/IcePatch2
%{_libdir}/mono/gac/IceStorm
%{_prefix}/lib/mono/gac/policy.*

%{_bindir}/iceboxnet.exe
%doc %{_mandir}/man1/iceboxnet.1.*

%files csharp-devel
%{_bindir}/slice2cs
%{_libdir}/pkgconfig/Glacier2.pc
%{_libdir}/pkgconfig/Ice.pc
%{_libdir}/pkgconfig/IceBox.pc
%{_libdir}/pkgconfig/IceGrid.pc
%{_libdir}/pkgconfig/IcePatch2.pc
%{_libdir}/pkgconfig/IceStorm.pc
%{_mandir}/man1/slice2cs.1.*
%endif

%files -n python3-%{name}
%{python3_sitearch}/*

%files -n python3-%{name}-devel
%{_bindir}/slice2py
%{_mandir}/man1/slice2py.1.*

%files ruby
%{ruby_vendorlibdir}/*
%{ruby_vendorarchdir}/*

%files ruby-devel
%{_bindir}/slice2rb
%{_mandir}/man1/slice2rb.1.*

%if %{with php}
%files -n php-%{name}
%{_libdir}/php/extensions/IcePHP.so
%config(noreplace) %{_sysconfdir}/php.d/ice.ini
# Move on a php-devel
%{_bindir}/slice2php
%{_mandir}/man1/slice2php.1.*
%endif


%changelog
* Sat Feb 01 2025 pterjan <pterjan> 3.7.10-3.mga10
+ Revision: 2144271
- Rebuild for Ruby 3.4

* Wed Dec 04 2024 pterjan <pterjan> 3.7.10-2.mga10
+ Revision: 2120945
- Rebuild for Ruby 3.3

* Thu Dec 28 2023 joequant <joequant> 3.7.10-1.mga10
+ Revision: 2023075
- upgrade to py3.12

* Thu Mar 31 2022 umeabot <umeabot> 3.7.7-3.mga9
+ Revision: 1837358
- Mageia 9 Mass Rebuild

* Fri Feb 25 2022 pterjan <pterjan> 3.7.7-2.mga9
+ Revision: 1784563
- Rebuild for Ruby 3.1

* Tue Feb 22 2022 tv <tv> 3.7.7-1.mga9
+ Revision: 1782936
- 3.7.7
- Rebuild for python-3.10
+ wally <wally>
- rebuild for openssl 3.0.0

* Fri Mar 26 2021 barjac <barjac> 3.7.5-1.mga9
+ Revision: 1710556
- new version 3.7.5
- new BR libedit
- dont ignore deprecated

* Fri Mar 26 2021 daviddavid <daviddavid> 3.7.4-4.mga9
+ Revision: 1710363
- rebuild for python 3.9

* Mon Dec 28 2020 neoclust <neoclust> 3.7.4-3.mga8
+ Revision: 1664486
- Remove useless DB_FLAGS command
- Build against db 5.3

* Sun Oct 25 2020 wally <wally> 3.7.4-1.mga8
+ Revision: 1639307
- new version 3.7.4
- build with openssl 1.1

* Mon May 18 2020 wally <wally> 3.7.3-2.mga8
+ Revision: 1585999
- switch to python3 build

* Mon Mar 30 2020 pterjan <pterjan> 3.7.3-1.mga8
+ Revision: 1562469
- Fix build on i586
- Fix disabling some languages and file lists
- Update to 3.7.3, 3.5.1 is from 2013...
- Rebuild for ruby 2.7
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 3.5.1-19.mga7
+ Revision: 1298262
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 wally <wally> 3.5.1-18.mga7
+ Revision: 1251347
- fix libdir on aarch64

* Sun Aug 12 2018 wally <wally> 3.5.1-17.mga7
+ Revision: 1251198
- use patch from Fedora to add arm/aarch64 support

* Mon Jan 01 2018 pterjan <pterjan> 3.5.1-16.mga7
+ Revision: 1188458
- Rebuild for Ruby 2.5

* Wed Nov 22 2017 tv <tv> 3.5.1-15.mga7
+ Revision: 1178565
- rebuild for new openssl

* Fri Oct 13 2017 wally <wally> 3.5.1-13.mga7
+ Revision: 1171651
- fix dir-or-file-in-usr-local rpmlint error which is preventing pkg upload to mirrors
+ tv <tv>
- build with compat-openssl10-devel
- drop php support as php is linked with new OpenSSL
+ pterjan <pterjan>
- Rebuild for new Ruby

* Wed Mar 02 2016 umeabot <umeabot> 3.5.1-11.mga6
+ Revision: 983480
- Rebuild for openssl

* Thu Feb 11 2016 umeabot <umeabot> 3.5.1-10.mga6
+ Revision: 954340
- Mageia 6 Mass Rebuild
+ pterjan <pterjan>
- Add patch for ruby 2.2

* Sun Nov 30 2014 sander85 <sander85> 3.5.1-8.mga5
+ Revision: 800095
- Disable java

* Thu Oct 16 2014 luigiwalser <luigiwalser> 3.5.1-7.mga5
+ Revision: 757709
- sync patches with fedora to fix build with java8
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Sat May 31 2014 pterjan <pterjan> 3.5.1-3.mga5
+ Revision: 628259
- Rebuild for new Python

* Thu Jan 09 2014 pterjan <pterjan> 3.5.1-2.mga4
+ Revision: 565948
- Fix hack
- Hack for usrmove to not replace .so symlinks with the libs

* Thu Jan 09 2014 dmorgan <dmorgan> 3.5.1-1.mga4
+ Revision: 565800
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Sep 21 2013 fwang <fwang> 3.4.2-5.mga4
+ Revision: 482712
- rebuild for ruby 2.0

* Tue Jul 30 2013 joequant <joequant> 3.4.2-4.mga4
+ Revision: 461159
- remove java-nodeps from buildrequires

* Sat Jan 12 2013 umeabot <umeabot> 3.4.2-3.mga3
+ Revision: 354115
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 fwang <fwang> 3.4.2-2.mga3
+ Revision: 331637
- fix requires of ruby binding

* Sun Dec 16 2012 fwang <fwang> 3.4.2-1.mga3
+ Revision: 331619
- update file list
- update file list
- update file list
- update file list
- requires dbjava
- update file list
- more str fmt fix
- build with php 5.4
- fix str fmt
- build with system jgoodies
- fix build with recent java
- use db4.8
- use db4.8
- br db 4.8
- br db 4.8
- fix build with recent gcc
- rediff some patches
- new version 3.4.2
- add includedir
- cleanup spec
- fix build
- rediff some patches
- new version 3.5b
- more patch
- fix patch
- more patch on building
- br db 5.2
+ malo <malo>
- update RPM group
+ stormi <stormi>
- rebuild for new glibc

* Mon Mar 19 2012 fwang <fwang> 3.3.1-5.mga2
+ Revision: 224290
- more patches
- more patch
- fix build
- fix build with new gcc

* Thu Mar 24 2011 boklm <boklm> 3.3.1-4.mga1
+ Revision: 76158
- rebuild for bug #497

* Wed Mar 09 2011 ennael <ennael> 3.3.1-3.mga1
+ Revision: 67193
- remove unexisting image
- clean spec file
- imported package ice

